Rename getActivatedXxx to getActiveXxx

Change-Id: Iba6d2805a69d3385c93b7ed3c6267b5b8b252a28
diff --git a/telephony/java/com/android/internal/telephony/ISub.aidl b/telephony/java/com/android/internal/telephony/ISub.aidl
index 507b017..e3b7d59 100755
--- a/telephony/java/com/android/internal/telephony/ISub.aidl
+++ b/telephony/java/com/android/internal/telephony/ISub.aidl
@@ -66,11 +66,11 @@
     int getAllSubInfoCount();
 
     /**
-     * Get the count of activated SUB(s)
+     * Get the count of active SUB(s)
      * @param context Context provided by caller
-     * @return activated SIM count
+     * @return active SIM count
      */
-    int getActivatedSubInfoCount();
+    int getActiveSubInfoCount();
 
     /**
      * Add a new SubInfoRecord to subinfo database if needed
@@ -164,5 +164,5 @@
 
     void clearDefaultsForInactiveSubIds();
 
-    long[] getActivatedSubIdList();
+    long[] getActiveSubIdList();
 }
diff --git a/telephony/java/android/telephony/SubscriptionManager.java b/telephony/java/android/telephony/SubscriptionManager.java
index 0d61f57..f83f164 100644
--- a/telephony/java/android/telephony/SubscriptionManager.java
+++ b/telephony/java/android/telephony/SubscriptionManager.java
@@ -316,16 +316,16 @@
     }
 
     /**
      * Get the count of activated SUB(s)
      * @return activated SIM count
      */
-    public static int getActivatedSubInfoCount() {
+    public static int getActiveSubInfoCount() {
         int result = 0;
 
         try {
             ISub iSub = ISub.Stub.asInterface(ServiceManager.getService("isub"));
             if (iSub != null) {
-                result = iSub.getActivatedSubInfoCount();
+                result = iSub.getActiveSubInfoCount();
             }
         } catch (RemoteException ex) {
             // ignore it
@@ -813,16 +813,16 @@
     }
 
     /**
      * @return the list of subId's that are activated,
      *         is never null but the length maybe 0.
      */
-    public static long[] getActivatedSubIdList() {
+    public static long[] getActiveSubIdList() {
         long[] subId = null;
 
         try {
             ISub iSub = ISub.Stub.asInterface(ServiceManager.getService("isub"));
             if (iSub != null) {
-                subId = iSub.getActivatedSubIdList();
+                subId = iSub.getActiveSubIdList();
             }
         } catch (RemoteException ex) {
             // ignore it
@@ -316,16 +316,16 @@
 
     /**
-     * Get the count of activated SUB(s)
-     * @return activated SIM count
+     * Get the count of active SUB(s)
+     * @return active SIM count
      */
@@ -813,16 +813,16 @@
 
     /**
-     * @return the list of subId's that are activated,
+     * @return the list of subId's that are active,
      *         is never null but the length maybe 0.
      */